@@ -78,6 +78,9 @@ export function adapterFactory({window} = {}, options = {
       firefoxShim.shimSenderGetStats(window);
       firefoxShim.shimReceiverGetStats(window);
       firefoxShim.shimRTCDataChannel(window);
+      firefoxShim.shimAddTransceiver(window);
+      firefoxShim.shimCreateOffer(window);
+      firefoxShim.shimCreateAnswer(window);
 
       commonShim.shimRTCIceCandidate(window);
       commonShim.shimConnectionState(window);
